@@ -703,7 +703,7 @@ class SME_Solver:
             sme.uncs = np.ones(sme.spec.size)
             logger.warning("SME Structure has no uncertainties, using all ones instead")
         if "mask" not in sme:
-            sme.mask = np.full(sme.wave.size, MASK_VALUES["line"])
+            sme.mask = np.full(sme.wave.size, MASK_VALUES.LINE)
 
         segments = Synthesizer.check_segments(sme, segments)
 
@@ -749,7 +749,7 @@ class SME_Solver:
 
         # Get constant data from sme structure
         for seg in segments:
-            sme.mask[seg, sme.uncs[seg] == 0] = MASK_VALUES["bad"]
+            sme.mask[seg, sme.uncs[seg] == 0] = MASK_VALUES.BAD
         mask = sme.mask_line[segments]
         spec = sme.spec[segments][mask]
         uncs = sme.uncs[segments][mask]
